=========================
GLM: First level analysis
=========================

These are examples focused on showcasing first level models functionality and single subject analysis.

See :ref:`glm` for more details.
